# Shopify Python Library - SPyLib

The Shopify python library, or SPyLib, simplifies the use of the Shopify
services such as the REST and GraphQL APIs as well as the OAuth authentication.
All of this is done **asynchronously using asyncio**.

![Tests](https://github.com/SatelCreative/satel-spylib/actions/workflows/tests.yml/badge.svg)
[![pypi](https://img.shields.io/pypi/v/spylib.svg)](https://pypi.python.org/pypi/spylib)
[![versions](https://img.shields.io/pypi/pyversions/spylib.svg)](https://github.com/SatelCreative/spylib)
[![license](https://img.shields.io/github/license/SatelCreative/spylib.svg)](https://github.com/SatelCreative/spylib/blob/main/LICENSE)

## Installation

```bash
pip install spylib
```

## What can SPyLib do?

[Official documentation](https://satelcreative.github.io/spylib)

Shopify components managed by SPyLib:

* Admin API
* Install an app through OAuth
* Session tokens
* Webhooks
* Multipass
